[![Build Status](https://travis-ci.com/simonpf/artssat.svg?branch=master)](https://travis-ci.com/simonpf/artssat)

# artssat

artssat provides a high-level, object-oriented interface for the [Atmospheric Radiative Transfer Simulator](https://www.radiativetransfer.org/). The aim of artssat is to provide a simpler and more modular way of performing radiative transfer simulations and in particular retrievals.

As of now, artssat is only used for my own research on remote sensing retrievals but I hope to
be able to expand its capabilities over time.

## Documentation

Source code documentation is hosted on the projects [Github pages site](https://simonpf.github.io/artssat).

